@@ -1,9 +1,8 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id$ */
+/* $Id: clock.c 562 2004-04-09 20:22:17Z roms $ */
 
-/*  TiLP - Tilp Is a Linking Program
- *  Copyright (C) 1999-2006  Romain Lievin
- *  Copyright (C) 2007  Kevin Kofler
+/*  tilp - Ti Linking Program
+ *  Copyright (C) 1999-2004  Romain Lievin
  *
  *  This program is free software you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,36 +15,34 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software Foundation,
- *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ *  along with this program if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
-#endif
+#endif				/*  */
 
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <string.h>
-#include <time.h>
 
-#include "support.h"
 #include "clock.h"
 #include "tilp_core.h"
 
+static TicalcClock tmp_clk;
 static GladeXML *xml;
 static gboolean modified;
-static CalcClock tmp_clk;
 
-static void update_fields(const CalcClock* clk)
+static void update_fields(const TicalcClock * clk)
 {
 	GtkWidget *data;
 
 	data = glade_xml_get_widget(xml, "spinbutton1");
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data), clk->day);
 	
-	data = glade_xml_get_widget(xml, "combobox1");
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data), clk->month - 1);
+	data = glade_xml_get_widget(xml, "optionmenu1");
+	gtk_option_menu_set_history(GTK_OPTION_MENU(data), clk->month - 1);
 
 	data = glade_xml_get_widget(xml, "spinbutton3");
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data), clk->year);
@@ -60,90 +57,63 @@ static void update_fields(const CalcClock* clk)
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data), clk->seconds);
 	
 	data = glade_xml_get_widget(xml, "radiobutton1");
-	if(clk->time_format == 12)
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data), TRUE);
+	if (clk->time_format == 12)
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data),
+					     TRUE);
 
 	data = glade_xml_get_widget(xml, "radiobutton2");
-	if(clk->time_format == 24)
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data), TRUE);
+	if (clk->time_format == 24)
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data),
+					     TRUE);
 
-	data = glade_xml_get_widget(xml, "combobox2");
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data), clk->date_format - 1);
+	data = glade_xml_get_widget(xml, "optionmenu2");
+	gtk_option_menu_set_history(GTK_OPTION_MENU(data), 
+				    clk->date_format - 1);
 }
 
 gint display_clock_dbox()
 {
 	GtkWidget *dbox;
 	gint result;
-	int err;
 
-	if(!(ticalcs_calc_features(calc_handle) & OPS_CLOCK))
-	{
-		gif->msg_box1(_("Error"), _("No clock support!"));
+	if (!(ti_calc.supported_operations() & OPS_CLOCK)) {
+		tilp_error(ERR_VOID_FUNCTION);
 		return -1;
 	}
-
-	err = ticalcs_calc_isready(calc_handle);
-	if(err)
-	{
-		tilp_err(err);
+	if (tilp_calc_isready())
 		return -1;
-	}
-
-	if(tilp_calc_check_version("2.08") < 0)
+	if (tilp_error(ti_calc.get_clock(&tmp_clk, 0)))
 		return -1;
-
-	err = ticalcs_calc_get_clock(calc_handle, &tmp_clk);
-	if(err)
-	{
-		tilp_err(err);
-		return -1;
-	}
-
-	tilp_info("%02i/%02i/%02i %02i:%02i:%02i, %s, %s\n", tmp_clk.day,
+	printl(0, "%02i/%02i/%02i %02i:%02i:%02i, %s, %s\n", tmp_clk.day,
 		tmp_clk.month, tmp_clk.year, tmp_clk.hours,
 		tmp_clk.minutes, tmp_clk.seconds,
 		(tmp_clk.time_format == 12) ? "12" : "24",
-		ticalcs_clock_format2date(options.calc_model, tmp_clk.date_format));
-
-	xml = glade_xml_new(tilp_paths_build_glade("clock-2.glade"), "clock_dbox", PACKAGE);
-	if(!xml)
+		ticalc_format_to_date(tmp_clk.date_format));
+	xml =
+	    glade_xml_new(tilp_paths_build_glade("clock-2.glade"),
+			  "clock_dbox", PACKAGE);
+	if (!xml)
 		g_error(_("action.c: GUI loading failed !\n"));
 	glade_xml_signal_autoconnect(xml);
-
 	dbox = glade_xml_get_widget(xml, "clock_dbox");
-	gtk_dialog_set_alternative_button_order(GTK_DIALOG(dbox), GTK_RESPONSE_OK,
-	                                        GTK_RESPONSE_CANCEL,-1);
 	update_fields(&tmp_clk);
 	modified = FALSE;
-
+	while (gtk_events_pending())
+		gtk_main_iteration();
 	result = gtk_dialog_run(GTK_DIALOG(dbox));
-	switch (result) 
-	{
+	switch (result) {
 	case GTK_RESPONSE_OK:
-		if(modified == FALSE)
+		if (modified == FALSE)
 			break;
-
-		tilp_info("%02i/%02i/%02i %02i:%02i:%02i, %s, %s\n",
+		printl(0, "%02i/%02i/%02i %02i:%02i:%02i, %s, %s\n",
 			tmp_clk.day, tmp_clk.month, tmp_clk.year,
 			tmp_clk.hours, tmp_clk.minutes, tmp_clk.seconds,
 			(tmp_clk.time_format == 12) ? "12" : "24",
-			ticalcs_clock_format2date(options.calc_model, tmp_clk.date_format));
-
-		err = ticalcs_calc_isready(calc_handle);
-		if(err)
-		{
-			tilp_err(err);
-			return -1;
-		}
-
-		err = ticalcs_calc_set_clock(calc_handle, &tmp_clk);
-		if(err)
-		{
-			tilp_err(err);
-			return -1;
-		}
-
+			ticalc_format_to_date(tmp_clk.date_format));
+		if (tilp_calc_isready())
+			break;
+		if (tilp_error(ti_calc.set_clock(&tmp_clk, 0)))
+			break;
 		modified = FALSE;
 		break;
 	case GTK_RESPONSE_HELP:
@@ -152,7 +122,6 @@ gint display_clock_dbox()
 		break;
 	}
 	gtk_widget_destroy(dbox);
-
 	return 0;
 }
 
@@ -160,14 +129,12 @@ GLADE_CB void
 clock_radiobutton3_toggled(GtkToggleButton * togglebutton,
 			   gpointer user_data)
 {
-	tmp_clk.state = 1;
 } 
 
 GLADE_CB void
 clock_radiobutton4_toggled(GtkToggleButton * togglebutton,
 			   gpointer user_data)
 {
-	tmp_clk.state = 0;
 } 
 
 GLADE_CB void
@@ -186,20 +153,77 @@ clock_radiobutton2_toggled(GtkToggleButton * togglebutton,
 	modified = TRUE;
 } 
 
-GLADE_CB void
-on_clock_combobox1_changed             (GtkComboBox     *combobox,
-                                        gpointer         user_data)
+/*
+GLADE_CB void clock_entry2_changed(GtkEditable * editable,
+				     gpointer user_data)
 {
-	gint nitem = gtk_combo_box_get_active(combobox);
-	tmp_clk.month = nitem + 1;
+	gchar *ed = gtk_editable_get_chars(editable, 0, -1);
+	tmp_clk.date_format = ticalc_date_to_format(ed);
+	modified = TRUE;
+}
+*/
+
+GLADE_CB void comm_optionmenu2_changed     (GtkOptionMenu   *optionmenu,
+                                            gpointer         user_data)
+{
+	gint nitem = gtk_option_menu_get_history(optionmenu);
+	
+	tmp_clk.date_format = nitem + 1;
 }
 
-GLADE_CB void
-on_clock_combobox2_changed             (GtkComboBox     *combobox,
-                                        gpointer         user_data)
+/*
+#ifdef __WIN32__
+#define strcasecmp _stricmp
+#endif			
+GLADE_CB void clock_entry1_changed(GtkEditable * editable,
+				   gpointer user_data)
 {
-	gint nitem = gtk_combo_box_get_active(combobox);
-	tmp_clk.date_format = nitem + 1;
+	gchar *ed = gtk_editable_get_chars(editable, 0, -1);
+	if (!strcasecmp(ed, _("Jan")))
+		tmp_clk.month = 1;
+
+	else if (!strcasecmp(ed, _("Feb")))
+		tmp_clk.month = 2;
+
+	else if (!strcasecmp(ed, _("Mar")))
+		tmp_clk.month = 3;
+
+	else if (!strcasecmp(ed, _("Apr")))
+		tmp_clk.month = 4;
+
+	else if (!strcasecmp(ed, _("May")))
+		tmp_clk.month = 5;
+
+	else if (!strcasecmp(ed, _("Jun")))
+		tmp_clk.month = 6;
+
+	else if (!strcasecmp(ed, _("Jul")))
+		tmp_clk.month = 7;
+
+	else if (!strcasecmp(ed, _("Aug")))
+		tmp_clk.month = 8;
+
+	else if (!strcasecmp(ed, _("Sep")))
+		tmp_clk.month = 9;
+
+	else if (!strcasecmp(ed, _("Oct")))
+		tmp_clk.month = 10;
+
+	else if (!strcasecmp(ed, _("Nov")))
+		tmp_clk.month = 11;
+
+	else if (!strcasecmp(ed, _("Dec")))
+		tmp_clk.month = 12;
+	modified = TRUE;
+}
+*/
+
+GLADE_CB void comm_optionmenu1_changed     (GtkOptionMenu   *optionmenu,
+                                            gpointer         user_data)
+{
+	gint nitem = gtk_option_menu_get_history(optionmenu);
+	
+	tmp_clk.month = nitem + 1;
 }
 
 GLADE_CB void clock_spinbutton3_changed(GtkEditable * editable,
@@ -247,12 +271,11 @@ GLADE_CB void clock_sync_button_clicked(GtkButton * button,
 {
 	time_t tt;
 	struct tm *lt;
-	CalcClock tc;
-	int err;
+	TicalcClock tc;
 
 	time(&tt);
 	lt = localtime(&tt);
-	memcpy(&tc, &tmp_clk, sizeof(CalcClock));
+	memcpy(&tc, &tmp_clk, sizeof(TicalcClock));
 	tc.day = lt->tm_mday;
 	tc.month = lt->tm_mon + 1;
 	tc.year = lt->tm_year + 1900;
@@ -260,19 +283,10 @@ GLADE_CB void clock_sync_button_clicked(GtkButton * button,
 	tc.minutes = lt->tm_min;
 	tc.seconds = lt->tm_sec;
 
-	err = ticalcs_calc_isready(calc_handle);
-	if(err)
-	{
-		tilp_err(err);
+	if (tilp_calc_isready())
 		return;
-	}
-
-	err = ticalcs_calc_set_clock(calc_handle, &tc);
-	if(err)
-	{
-		tilp_err(err);
+	if (tilp_error(ti_calc.set_clock(&tc, 0)))
 		return;
-	}
 
 	update_fields(&tc);
 	modified = FALSE;
