@@ -1,8 +1,8 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: splash.c 3807 2007-09-23 19:57:06Z roms $ */
+/* $Id: splash.c 366 2004-03-22 18:04:07Z roms $ */
 
-/*  TiLP - Tilp Is a Linking Program
- *  Copyright (C) 1999-2006  Romain Lievin
+/*  tilp - Ti Linking Program
+ *  Copyright (C) 1999-2004  Romain Lievin
  *
  *  This program is free software you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,60 +30,55 @@
 
 #include "support.h"
 #include "tilp_version.h"
-#include "tilp_core.h"
-#include "gtk_update.h"
-
-typedef struct 
-{
+typedef struct {
 	GtkWidget *window;
 	GtkWidget *label;
 } TilpSplashScreen;
-
-static TilpSplashScreen ss;
-
+static TilpSplashScreen splashscreen;
 GtkWidget *splash_screen_start(void)
 {
 	GtkWidget *image, *vbox;
 	GdkColor color;
 	GdkPixbuf *pixbuf;
-
-	ss.window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title(GTK_WINDOW(ss.window),
+	splashscreen.window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title(GTK_WINDOW(splashscreen.window),
 			     TILP_VERSION);
-	gtk_window_set_position(GTK_WINDOW(ss.window),
+	gtk_window_set_position(GTK_WINDOW(splashscreen.window),
 				GTK_WIN_POS_CENTER_ALWAYS);
-	gtk_window_set_decorated(GTK_WINDOW(ss.window), FALSE);
-	gtk_window_set_role(GTK_WINDOW(ss.window), "splash");
-	gtk_window_set_resizable(GTK_WINDOW(ss.window), FALSE);
-	gtk_window_set_default_size(GTK_WINDOW(ss.window), 150, 150);
+	gtk_window_set_decorated(GTK_WINDOW(splashscreen.window), FALSE);
+	gtk_window_set_role(GTK_WINDOW(splashscreen.window), "splash");
+	gtk_window_set_resizable(GTK_WINDOW(splashscreen.window), FALSE);
+	gtk_window_set_default_size(GTK_WINDOW(splashscreen.window), 150, 150);
 	color.red = 65535;
 	color.blue = 65535;
 	color.green = 65535;
-	gtk_widget_modify_bg(ss.window, GTK_STATE_NORMAL,
+	gtk_widget_modify_bg(splashscreen.window, GTK_STATE_NORMAL,
 			     &color);
 	vbox = gtk_vbox_new(FALSE, 0);
-	gtk_container_add(GTK_CONTAINER(ss.window), vbox);
+	gtk_container_add(GTK_CONTAINER(splashscreen.window), vbox);
 	gtk_widget_show(vbox);
-	ss.label = gtk_label_new("starting TiLP...");
-	gtk_box_pack_end(GTK_BOX(vbox), ss.label, FALSE, FALSE, 0);
-	gtk_widget_show(ss.label);
-	pixbuf = create_pixbuf("logo.png");
+	splashscreen.label = gtk_label_new("starting TiLP...");
+	gtk_box_pack_end(GTK_BOX(vbox), splashscreen.label, FALSE, FALSE,
+			 0);
+	gtk_widget_show(splashscreen.label);
+	pixbuf = create_pixbuf("logo.xpm");
 	image = gtk_image_new_from_pixbuf(pixbuf);
 	gtk_box_pack_end(GTK_BOX(vbox), image, FALSE, FALSE, 0);
 	g_object_unref(pixbuf);
 	gtk_widget_show(image);
-	gtk_widget_show(ss.window);
-
-	return ss.window;
+	gtk_widget_show(splashscreen.window);
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	}
+	return splashscreen.window;
 }
-
 void splash_screen_stop(void)
 {
-	gtk_widget_destroy(ss.window);
-} 
-
-void splash_screen_set_label(gchar * label)
+	gtk_widget_destroy(splashscreen.window);
+} void splash_screen_set_label(gchar * label)
 {
-	gtk_label_set_text(GTK_LABEL(ss.label), label);
-	GTK_REFRESH();
+	gtk_label_set_text(GTK_LABEL(splashscreen.label), label);
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	}
 }
